@@ -5,8 +5,8 @@ import (
 	"reflect"
 	"testing"
 
-	"github.com/accurics/terrascan/pkg/config"
-	"github.com/accurics/terrascan/pkg/notifications/webhook"
+	"github.com/tenable/terrascan/pkg/config"
+	"github.com/tenable/terrascan/pkg/notifications/webhook"
 )
 
 func TestNewNotifier(t *testing.T) {
