@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2020 Accurics, Inc.
+    Copyright (C) 2022 Tenable, Inc.
 
 	Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -20,12 +20,12 @@ import (
 	"os"
 	"path/filepath"
 
-	scanUtils "github.com/accurics/terrascan/test/e2e/scan"
-	"github.com/accurics/terrascan/test/helper"
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/gomega"
 	"github.com/onsi/gomega/gbytes"
 	"github.com/onsi/gomega/gexec"
+	scanUtils "github.com/tenable/terrascan/test/e2e/scan"
+	"github.com/tenable/terrascan/test/helper"
 )
 
 var _ = Describe("Scan Command using remote types", func() {
@@ -138,7 +138,7 @@ var _ = Describe("Scan Command using remote types", func() {
 
 	Context("valid remote type is supplied with valid remote URL", func() {
 		When("remote type is git", func() {
-			remoteURL := "github.com/accurics/KaiMonkey/terraform/aws"
+			remoteURL := "github.com/tenable/kaimonkey/terraform/aws"
 			It("should download the resource and generate scan results", func() {
 				scanArgs := []string{scanUtils.ScanCommand, "-r", "git", "--remote-url", remoteURL}
 				session = helper.RunCommand(terrascanBinaryPath, outWriter, errWriter, scanArgs...)
@@ -148,7 +148,7 @@ var _ = Describe("Scan Command using remote types", func() {
 			})
 
 			It("should download the resource and generate scan results", func() {
-				remoteURL := "https://github.com/accurics/KaiMonkey.git//terraform/aws"
+				remoteURL := "https://github.com/tenable/kaimonkey.git//terraform/aws"
 				scanArgs := []string{scanUtils.ScanCommand, "-r", "git", "--remote-url", remoteURL}
 				session = helper.RunCommand(terrascanBinaryPath, outWriter, errWriter, scanArgs...)
 				// exit code is 5 because iac files in directory has violations
@@ -232,7 +232,7 @@ var _ = Describe("Scan Command using remote types", func() {
 	})
 	Context("when scan is run using custom temp directory with env variable", func() {
 		When("remote type is git", func() {
-			remoteURL := "github.com/accurics/KaiMonkey/terraform/aws"
+			remoteURL := "github.com/tenable/kaimonkey/terraform/aws"
 			tmpDir, err := filepath.Abs(filepath.Join(iacRootRelPath, "temp_dir"))
 			Expect(err).NotTo(HaveOccurred())
 			JustBeforeEach(func() {
@@ -256,7 +256,7 @@ var _ = Describe("Scan Command using remote types", func() {
 	})
 	Context("when scan is run on remote dir and using flag --temp-dir to set custom temp dir", func() {
 		When("remote type is git", func() {
-			remoteURL := "github.com/accurics/KaiMonkey/terraform/aws"
+			remoteURL := "github.com/tenable/kaimonkey/terraform/aws"
 			tmpDir, err := filepath.Abs(filepath.Join(iacRootRelPath, "temp_dir"))
 			Expect(err).NotTo(HaveOccurred())
 			It("should download the resource in provided custom temp dir and generate scan results", func() {
